@@ -1190,7 +1190,6 @@ class Language:
         get_examples: Optional[Callable[[], Iterable[Example]]] = None,
         *,
         sgd: Optional[Optimizer] = None,
-        link_components: bool = True,
     ) -> Optimizer:
         """Initialize the pipe for training, using data examples if available.
 
@@ -1198,8 +1197,6 @@ class Language:
             returns gold-standard Example objects.
         sgd (Optional[Optimizer]): An optimizer to use for updates. If not
             provided, will be created using the .create_optimizer() method.
-        link_components (bool): Link listener components automatically or not
-            (default True)
         RETURNS (thinc.api.Optimizer): The optimizer.
 
         DOCS: https://spacy.io/api/language#initialize
@@ -1247,8 +1244,7 @@ class Language:
                     proc.initialize, p_settings, section="components", name=name
                 )
                 proc.initialize(get_examples, nlp=self, **p_settings)
-        if link_components:
-            self._link_components()
+        self._link_components()
         self._optimizer = sgd
         if sgd is not None:
             self._optimizer = sgd
